"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTests = exports.Action = void 0;
const path_1 = __importDefault(require("path"));
const testFailures_1 = require("./testFailures");
const exec_1 = require("../shell/exec");
exports.Action = {
    RUN_NIGHTWATCH_START: '@@night-patrol/nightwatch/RUN_NIGHTWATCH_START',
    RUN_NIGHTWATCH_SUCCESS: '@@night-patrol/nightwatch/RUN_NIGHTWATCH_SUCCESS',
    RUN_NIGHTWATCH_FAILURE: '@@night-patrol/nightwatch/RUN_NIGHTWATCH_FAILURE'
};
const runNightWatchStart = (nightWatchArgs) => ({
    type: exports.Action.RUN_NIGHTWATCH_START,
    payload: nightWatchArgs
});
const runNightWatchSuccess = () => ({
    type: exports.Action.RUN_NIGHTWATCH_SUCCESS
});
const runNightWatchFailure = () => ({
    type: exports.Action.RUN_NIGHTWATCH_FAILURE
});
exports.runTests = ({ suite, testname }) => ((dispatch, getState) => {
    const { config: { configPath, executablePath, currentEnvironment, suites } } = getState();
    const nightWatchArgs = {
        config: configPath,
        env: currentEnvironment
    };
    if (suite) {
        nightWatchArgs.test = path_1.default.resolve(`${suite}.js`);
    }
    if (testname) {
        nightWatchArgs.testcase = testname;
    }
    dispatch(runNightWatchStart(nightWatchArgs));
    return exec_1.exec(executablePath, nightWatchArgs)
        .then(() => {
        if (suite && testname) {
            return dispatch(testFailures_1.removeTestFailure({
                suiteName: suite,
                testName: testname
            }));
        }
        if (suite) {
            return dispatch(testFailures_1.clearTestFailuresForSuite({ suiteName: suite }));
        }
        return dispatch(testFailures_1.clearTestFailures());
    })
        .then(() => {
        dispatch(runNightWatchSuccess());
    })
        .catch(({ stdout }) => {
        dispatch(testFailures_1.addTestFailuresFromNightwatchOutput({ suites, stdout }));
        dispatch(runNightWatchFailure());
    });
});
//# sourceMappingURL=nightwatch.js.map