"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createConfig = void 0;
const lodash_1 = require("lodash");
const path_1 = __importDefault(require("path"));
const ensureArray_1 = require("../utils/ensureArray");
const getDefaultConfig_1 = require("./getDefaultConfig");
const getSuites_1 = require("./getSuites");
const createConfig = (options = {}) => {
    const config = getDefaultConfig_1.getDefaultConfig();
    if (options.configPath) {
        config.configPath = path_1.default.resolve(options.configPath);
    }
    if (options.executablePath) {
        config.executablePath = path_1.default.resolve(options.executablePath);
    }
    if (options.currentEnvironment) {
        config.currentEnvironment = options.currentEnvironment;
    }
    if (options.currentSuite) {
        config.currentSuite = options.currentSuite;
    }
    try {
        delete require.cache[require.resolve(config.configPath)];
        const nightwatchConfig = require(config.configPath);
        if (nightwatchConfig.test_settings) {
            config.environments = Object.keys(nightwatchConfig.test_settings)
                .reduce((acc, next) => {
                acc[next] = true;
                return acc;
            }, {});
        }
        if (lodash_1.isEmpty(config.environments)) {
            throw new Error('Provided Nightwatch Config has no environments (config.test_settings).');
        }
        if (!config.environments[config.currentEnvironment]) {
            config.currentEnvironment = Object.keys(config.environments)[0];
        }
        config.suiteDirectories = ensureArray_1.ensureArray(nightwatchConfig.src_folders)
            .map(dir => path_1.default.resolve(dir));
        config.suites = getSuites_1.getSuites(config.suiteDirectories);
    }
    catch (e) {
        config.error = `${e.stack || e}`;
    }
    return config;
};
exports.createConfig = createConfig;
//# sourceMappingURL=createConfig.js.map